;
EEPROM_Code_Version  code_pack   0xf0006A
        db  .0      ;Low Byte of Version
        db  .1      ;High Byte of Version
;
;
;  Config Constants for 1.4 Amp Hours 12V AGM Lead Acid
;
;
    Global      EE_VBatLow
;
;
;          org 0xF00000
Bat_Config    code_pack   0xF00000;
;
;  The first group of EEPROM constants are loaded into process memory. This 
;  allows these frequently used paramters to be quickly accessed.																			 
;
EE_VCharger_Min         DE  D'4'       ;Lowest Operating point          .6 Volts
EE_VCharger_Start       DE  D'6'       ;DC Converter start point        .9 Volts
EE_VCharger_Max			DE	D'77'		;Max Operating value is         12   Volts
;
; The BatChrgMax, BatChrgStart and VBatMin are 20 degree values. 
;
;Index[3]
EE_VBatChrgMax          DE  D'91'       ;Max Battery Voltage during Charging 14.3 Volts
EE_VBatChrgStart        DE  D'77'       ;Start Charging Voltage              12.0 Volts
EE_VBatMin              DE  D'57'       ;Min Battery Voltage (Cut Off)     	  9.0 Volts
EE_ILoadMax				DE  D'194'		;Maximum Load Current 12.9ma steps    2.5 Amp;
;That ends the RAM Copied EE values
;
; The following EE Parameters are not loaded into RAM
;
;Index[7]
EE_Gas_Prescale         DE  D'1'        ;Prescale Gas Guage by 1
EE_BatSize_High         DE high D'1400' ;High Byte of Battery Capacity		  7 AHr
EE_BatSize_Low          DE low  D'1400' ;Low Byte of Basttery Capacity
EE_BatPartialHigh       DE high D'1260' ;High Byte of Partial Charge
EE_BatPartialLow        DE low  D'1260' ;Low Byte of Partial Charge
EE_BatReserveHigh       DE high D'0000' ;High Byte of Reserve Charge
EE_BatReserveLow        DE low  D'0000' ;Low Byte of Partial Charge


;
;  We have 2 battery constants that are related to cell chemistry
;
; Index[14] 0x0e
EE_VSetPartial          DE  D'87'      ;Partially charged volts @ 20 C    13.7 Volts
EE_VBatClrFail			DE	D'73'	   ;Point where BatFailed is cleared  11.5 Volts


;
;
;* Do not move these as they are expected in sequence. High first Low second.
;*
;*  We need constants to cut off battery charging when the temperature is to high or low
;*  0 = -40      6 = -10     12 =  20      18 =  50    24 =  80
;*  1 = -35      7 =  -5     13 =  25      19 =  55
;*  2 = -30      8 =   0     14 =  30      20 =  60
;*  3 = -25      9 =   5     15 =  35      21 =  65
;*  4 = -20     10 =  10     16 =  40      22 =  70
;*  5 = -15     11 =  15     17 =  45      23 =  75
;*
EE_MaxChargeTemp		DE	D'16'		;Above this No Charging 16 =  40C
EE_MinChargeTemp		DE  D'4'		;Below this No Charge    4 = -20C
;*
;
;  The TopOff Time is used to extend charging time by a fixed duration
;  of time. This helps make sure the Battery is fully charged.
;
;  Upper 2 Bits  Time Scale
;      0x00      = Count every minute
;      0x40      = Count every 10 Minutes
;      0x80      = Count every Hour
;      0xC0      = Count every 10 Hour (8 hours on average, Rolls Over from 24)
;
;
EE_TopOff_Time          DE  (0x00 + D'60')     ;Top off timer 60 Min 1 Hours
;
;
;
;  When an external transistor is used to create a constant current
;  charger then the EE_ICharger is use directly as an indication of
;  the level of the charging current. Each count in EE_ICharger indicates
;  14ma of charging current.
;
;    EE_ICharger = Charging_Current / 14
;
;  For example for a 250ma charging current EE_ICharger = 250 / 14 = 17.8 = 18  
;
;
EE_ICharger				DE D'36'		;Setup for 500ma
;
;
;* Do not move K1 and K2 from each other. They are accessed in sequence.
;*
;* We have 2 Constants used to control Gas Gauge Discharge
;*
;* Discharge Current = K1 * .711 * ( IAvg + (K2 * (IAvg**2)))
;*
;* .711 comes from the fact IAvg is in 10ma step, added once per second 
;*  and the Gas Gauge is in mahr. 
;*
; * K1 Represents the effective battery capacity. 
; * (.9 reserves 10% of capacity below Gas Gauge = 0)
;*
;*  The K2 is a fractions between 0 and 1. (255 = 255/256   1 = 1/256)
;*
;*   .711 = D'182'  We combine K1 and .711 into a single constant
;* 
EE_Constant_K2          DE D'128'        ;K2 = .5
EE_Constant_K1          DE D'214'        ;K1 = .90  214 = 182/.90
;*
;
; We have a value that defines a battery warning point which is defined in terms of voltage.
; The value is used to control the RED Status LED if there is a two LED Display.
;
; Index[22]
EE_VBatLow        		DE  D'67'		;Low Battery Voltage  10.5 Volts
;
;
;
;  We need a table to compute a battery voltage compensation value given
;  a temperature. BatTemp is used where:
; BatTemp  T      VComp
;     0   -40       2 
;     1   -35                9    5              17   45
;     2   -30   1   1       10   10    0   1     18   50   0   -1
;     3   -25               11   15              19   55
;     4   -20   0   1       12   20    1   0     20   60   1   -2
;     5   -15               13   25              21   65
;     6   -10   0   1       14   30    0   0     22   70   1   -3
;     7    -5               15   35              23   75
;     8     0   0   1       16   40    1  -1     24   80   1   -4
;
;  We leave this table in EEPROM, it is not read into RAM. This table allows for 8
;  linear approzimation slopes. The first value contains the sign bit of the compensation results
;  and a 7 bit twos complement of the start point. The following bytes are 6 bytes each of which
;  contains two 4 bit values. These 12 bit values are associated with 10 degree increments from
;  -30 to +80C. The temperaturs compensation value is formed byt using the Battery Temp value (0 - 24)
;  and for every 2 counts in BatTemp we add/subtract a 4 bit value to the Starting Value. If the
;  BatTemp is odd we use 1/2 of the next 4 bit value giving up 5 degree resolution.
;
; Index[23]
EE_TempCompTable
			DE 	(0x80 + D'12')	;Set MSB for Neg Temp Coeff. Start at 14  -40C
			DE	0x00			; 12  12   -30C  -20C
			DE	0x44			;  8   4   -10C    0C
;
			DE	0x22			;  2   0    10C   20C
			DE	0x21			; -2  -3    30C   40C
;
			DE	0x11			; -4  -5    50C   60C
			DE	0x11            ; -6  -7    70C   80C
;
;
;
; We need a constant that identifies Battery Self Discharge current. This setting is the 20C 
; setting with the level of self discharge doubling ever 20C. Each count represents 29ua of 
; self discharge. If we assume a 3200mahr battery looses 100% in 4 months (2933 hrs) then the
; self discharge is 3200 / 2933 = 1090ua. (730 Hours / Month)
;
;  SelfDischageValue = 1090 / 29 = 36
;
; Index[30]
EE_BatSelfDis           DE  D'5'  ;20% (280mahr) in 4 months = 95ua so 95/29 = 3
;
;*
;*  Don't Move BatCond_Days and BatDischarge. They must be sequential
;*
;*  We have the ability to do a Battery Condition Cycle every so many days
;*  Setting EE_BatCond_Days to > 0 causes the TopOff Timer to be
;*  started every so many days. A setting of 0 stops condition cycles.
;*
EE_BatCond_Days         DE  D'60'        ;Battery Condition Timer
;*
;*
;*  We need a parameter that defines the time between battery discharge cycles. We
;*  Once a month we bump down this count. When it hits zero we do a bat discharge.
;*  A Setting of zero disables battery discharge cycles. 
;*
;*  4 low bits are the month down counter. Max of 15 months. 100ma discharge is
;*  common, other bits specify other discharge currents.
;*
;*
EE_BatDischarge			DE		D'0'		;Zero months
BatDis_Req				equ		4			;High when discharging battery required
BatDis_500ma			equ		5			;When high discharge current is 500ma
BatDis_1Amp				equ		6			;When high discharge current is 1Amp
;*						Bit 3 - 0			;Low 4 bits bump down every month
;*
;
;  We need a constant used to scale the load current as we feed
;  this into the Gas Accumulator. This constant has a fractional
;  part in the low 4 bit and an integer portion in the high 4 bits. 
;  If the fraction is not equal to 0 we multiply IAvg by this fraction
;  If the fraction is = 0 then we use IAvg straight.
;
;  The Integer portion is used as a loop counter for "Multiple Subtracts"
;  of the final result to the Gas Gauge.
;
; Index[33]
EE_GasSubFactor			DE	0x20
;
;  We need a set of values that identifies the scaling of the Analog to
;  Digital converter channels
;
;  These values are not used in PIC code, they are simply used to reflect
;  how the hardware is (or at least should be) stuffed. Different
;  resistor stuffings affect the full scale voltage reading. By
;  putting these values in EEPROM an external application can 
;  present analog values to the user in volts and amps.
;
;  Normal battery setup software should NOT change these since they
;  reflect resistor stuffings. Manufacturing stware MUST set these
;  to keep displayed values in sync with actual analog values.
;
;Index[34] 0x22
EE_FS_VIn				DE	D'40'		;Full Scale Volts for Vin at 0x100 
EE_FS_VRun				DE	D'40'		;Full Scale Volts for VRun at 0x100
EE_FS_ILoad				DE	D'66'		;Full Scale (Amps * 10) for ILoad at 0x100
EE_FS_IIn				DE	D'66'		;Full Scale Amps for Iin at 0x100
;
;
;  The WDT needs 2 times. The time OFF time which gives the system
;  a complete power off and the ON time which gives the system a 
;  chance to boot.
;
;Index[38]
EE_WDT_TimeOn			DE D'120'			;On Time of WDT Cycle in Seconds
EE_WDT_TimeOff			DE D'30'			;Off time of WDT Cycle in Minutes
;
;
;  We need a safety timer that limits the total length of time
;  that a battery will Charge. We have a value in EEPROM used to
;  set that timer when we start charging.
;  We use the 2 MSB of the Max Charger Timer to select the count down
;  rate. The lower 6 bits are the counter
;
;  Upper 2 Bits  Time Scale
;      0x00      = Count every minute
;      0x40      = Count every 10 Minutes
;      0x80      = Count every Hour
;      0xC0      = Count every 10 Hour (8 hours on average, Rolls Over from 24)
;
EE_MaxChargeTime		DE (0x80 + D'10')	;10 Hours
;
;
; We need a setting to support efficient charging from solar panels. We enter here the
; Peak Power Voltage for Full Sun or something slightly below this point. Be certain
; and diode drops have been includes and remember that the peak voltage drops at
; higher temperatures.
;
; If a solar panel is not being used set EE_VSolar to 0xff
;
;		EE_VSolar				DE 0xff 		;No Solar Charging
;		EE_VSolar				DE D'115'		;target voltage for charging	18V
;
;Index [41] 0x29
EE_VSolar			DE	0xff
;
;  We have a User Location in EEPROM
;
EE_User1            DE      0x52	;Const Curr, Force On, Hold Mode
;
USR_ForceOn         equ		7		;MSB is Force On Bit
USR_OnFailUnLock    equ		6		;When a Battery Hit FAILED then clear any Lock Condition
USR_ResetPwrOn      equ		5		;When High the converter is turned ON after a Reset
USR_ForceHoldMode   equ		4		;Force Power On Mode to HOLD Mode
USR_Lock            equ		3		;When Set a ONOFF transistion DOES NOT clear a LOCK
;										;POWER ON condition. Useful for protecting FLASH
;USR_LowLedMode      equ		2		;When Set the serial output is force to drive a
									;HIGH output when the Battery is Low
USR_Force3_3Active  equ		1		;High keeps 3.3 Regulator active during sleep
USR_InstantOn       equ		0		;When High there is no 3 sec PowerLock delay at reset
;
;
;
;  Finally we have a checksum for EE Data
;
;Index[43]
EE_CheckSum             DE Low (-0xF0)  ;Twos Comp Checksum for above
;

