/* 
 * File:   SunD_ShowStatus.c
 */

#include <xc.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <stdarg.h>


#include "../SunDuino_V100.h"
#include "plib\i2c.h"

#include "SerialStatus.h"


//#define MAXCMD  40          //Max Chars in Command String
//#define MAXTKN  10          //Max chars in token
//#define RX_TimeOut 30       //Timeout in Seconds for forming Command Strings

/*
 * Since Microchip does not include a sscanf in their library we use a _doscan
 * routine that was pulled from the xc8 directory and slightly chopped up.
*/
int _doscan(const char * str, const char * fmt, ...);

extern void ShowSerialStatus (unsigned char SleepRes, unsigned char DidSleep);

int main(int argc, char** argv) {

    char    SleepRes,Sec,j,HighRes,DidSleep;
//    char    SleepRes,Hours,Min,Sec,j,HighRes,DidSleep;
//    float   VRun, VBat, VCharger;

    struct TPowerEvents     PowerEvents;
//    struct TPowerState      PowerState;
//    struct TBatteryStatus   BatteryStatus;

    Sec = 0;
    j = 0;
    SleepRes = 255;
    HighRes = 0;
    DidSleep = 0;
    RX_ProcessInit();       //Clear RX Character processing logic

// There are reset events and such on startup. We want to clear them.
    PowerEvents =  bb_getPowerEvents();
    bb_func_ClearEvents (PowerEvents);
    bb_func_PwrOnOff(0);    //Make sure Power is Off

// Add a little delay to allow the switch from Bootloader to Application screens
// as the user might have just switched using the GREEN ARROW on the bootloader.
    delay_ms(500);
    printf ("\n\rSunduino Test Program  -  Enter ? for Help\n\r\n\rBB>");

// Now we have an infinites loop for our application
    while (1) {
        HighRes = 0;        //Zero out var to collect the Highest Sleep Result
        DidSleep = 0;
        do
        {
/*
 *  Here we enter into a loop where we wait for 1 seconds to pass but we also need
 *  to process any incoming UART characters. Removing chars from the UART is
 * important as a waiting character will prevent the processor from going to sleep.
 * There are a set of RX_Process functions used to collect characters into a string,
 * decode commands in that string (RX_Command), timeout command collection and
 * initializ the coll3ction process.
 *
 * The idea is not to loose RX character and to keep the processor in sleep inbetween
 * character entry. During power up/down it is common to see junk characters arrive
 * in the UART and we cannot allow these to keep the processor from going to sleep
 */
            SleepRes = bb_func_DoSleep ();
            RX_Process ();                  //Check for incoming characters
//
// We have a little logic to monitor if we really did sleep (DidSleep) and we also
// collect the highest value of Sleep Results during our one Second Sleep routine.
            if (SleepRes > HighRes) HighRes = SleepRes;
            if (SleepRes == 0) DidSleep = 1;
            Sec = bb_time_getSeconds();
        } while ( Sec == j);
/*
 * Drop throught means Sec has bumped up by one. Thats happened in low
 * level ISR code in the Battery Boss where a Real Time Clock is maintained.
 */
        j = Sec;                            //Setup to detect next second.
        RX_ProcessTime ();                  //Every second do TX Timeout Logic

//        Hours = bb_time_getHours();
//        Min   = bb_time_getMinutes();
        HighRes = 0;
/*
 * Once every 10 seconds we want to dump the Battery Boss status. If the user is
 * entering a command the status will not display as doing so would mess
 * up the echos on the screen.
 */
        if ( (Sec % 10) == 4 )
        {
            ShowSerialStatus (SleepRes,DidSleep);
        }

    }
    return (EXIT_SUCCESS);  //Shuld never happen
}




